==> react-native-highlightable-text-1.5.0.tgz: package/android/src/main/java/com/alentoma/selectabletext/CustomReactTextViewManager.java <==
package com.alentoma.selectabletext;

import android.content.Context;
import android.text.Spannable;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import com.facebook.react.R.id;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableNativeMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.common.annotations.VisibleForTesting;
import com.facebook.react.common.mapbuffer.MapBuffer;
import com.facebook.react.module.annotations.ReactModule;
import com.facebook.react.uimanager.IViewManagerWithChildren;
import com.facebook.react.uimanager.ReactAccessibilityDelegate;
import com.facebook.react.uimanager.ReactStylesDiffMap;
import com.facebook.react.uimanager.StateWrapper;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.views.text.ReactTextAnchorViewManager;
import com.facebook.react.views.text.ReactTextShadowNode;
import com.facebook.react.views.text.ReactTextUpdate;
import com.facebook.react.views.text.ReactTextView;
import com.facebook.react.views.text.ReactTextViewManagerCallback;
import com.facebook.react.views.text.TextAttributeProps;
import com.facebook.react.views.text.TextInlineImageSpan;
import com.facebook.react.views.text.TextLayoutManager;
import com.facebook.react.views.text.TextLayoutManagerMapBuffer;
import com.facebook.yoga.YogaMeasureMode;
import java.util.HashMap;
import java.util.Map;

/*
    This is an exact copy of ReactTextViewManager, except it uses our custom elements like CustomReactClickableSpan, TextViewSelectionObserver.
*/
public class CustomReactTextViewManager extends ReactTextAnchorViewManager<TextViewSelectionObserver, ReactTextShadowNode> implements IViewManagerWithChildren {
    private static final short TX_STATE_KEY_ATTRIBUTED_STRING = 0;
    private static final short TX_STATE_KEY_PARAGRAPH_ATTRIBUTES = 1;
    private static final short TX_STATE_KEY_HASH = 2;
    private static final short TX_STATE_KEY_MOST_RECENT_EVENT_COUNT = 3;
    @VisibleForTesting
    public static final String REACT_CLASS = "RCTText";
    @Nullable
    protected ReactTextViewManagerCallback mReactTextViewManagerCallback;

    public CustomReactTextViewManager() {
        this((ReactTextViewManagerCallback)null);
    }

    public CustomReactTextViewManager(@Nullable ReactTextViewManagerCallback reactTextViewManagerCallback) {
        this.mReactTextViewManagerCallback = reactTextViewManagerCallback;
        this.setupViewRecycling();
    }

    protected TextViewSelectionObserver prepareToRecycleView(@NonNull ThemedReactContext reactContext, TextViewSelectionObserver view) {
        super.prepareToRecycleView(reactContext, view);
//        view.recycleView();
        this.setSelectionColor(view, (Integer)null);
        return view;
    }

    public String getName() {
        return "RCTText";
    }

    public TextViewSelectionObserver createViewInstance(ThemedReactContext context) {
        return new TextViewSelectionObserver(context);
    }

    public void updateExtraData(TextViewSelectionObserver view, Object extraData) {
        ReactTextUpdate update = (ReactTextUpdate)extraData;
        Spannable spannable = update.getText();
        if (update.containsImages()) {
            TextInlineImageSpan.possiblyUpdateInlineImageSpans(spannable, view);
        }

        view.setText(update);
        CustomReactClickableSpan[] clickableSpans = (CustomReactClickableSpan[])spannable.getSpans(0, update.getText().length(), CustomReactClickableSpan.class);
        if (clickableSpans.length > 0) {
            view.setTag(id.accessibility_links, new ReactAccessibilityDelegate.AccessibilityLinks(clickableSpans, spannable));
            ReactAccessibilityDelegate.resetDelegate(view, view.isFocusable(), view.getImportantForAccessibility());
        }

    }

    public ReactTextShadowNode createShadowNodeInstance() {
        return new ReactTextShadowNode(this.mReactTextViewManagerCallback);
    }

    public ReactTextShadowNode createShadowNodeInstance(@Nullable ReactTextViewManagerCallback reactTextViewManagerCallback) {
        return new ReactTextShadowNode(reactTextViewManagerCallback);
    }

    public Class<ReactTextShadowNode> getShadowNodeClass() {
        return ReactTextShadowNode.class;
    }

    protected void onAfterUpdateTransaction(TextViewSelectionObserver view) {
        super.onAfterUpdateTransaction(view);
        view.updateView();
    }

    public boolean needsCustomLayoutForChildren() {
        return true;
    }

    public Object updateState(TextViewSelectionObserver view, ReactStylesDiffMap props, StateWrapper stateWrapper) {
        MapBuffer stateMapBuffer = stateWrapper.getStateDataMapBuffer();
        if (stateMapBuffer != null) {
            return this.getReactTextUpdate(view, props, stateMapBuffer);
        } else {
            ReadableNativeMap state = stateWrapper.getStateData();
            if (state == null) {
                return null;
            } else {
                ReadableMap attributedString = state.getMap("attributedString");
                ReadableMap paragraphAttributes = state.getMap("paragraphAttributes");
                Spannable spanned = TextLayoutManager.getOrCreateSpannableForText(view.getContext(), attributedString, this.mReactTextViewManagerCallback);
                view.setSpanned(spanned);
                int textBreakStrategy = TextAttributeProps.getTextBreakStrategy(paragraphAttributes.getString("textBreakStrategy"));
                return new ReactTextUpdate(spanned, state.hasKey("mostRecentEventCount") ? state.getInt("mostRecentEventCount") : -1, false, TextAttributeProps.getTextAlignment(props, TextLayoutManager.isRTL(attributedString)), textBreakStrategy, TextAttributeProps.getJustificationMode(props));
            }
        }
    }

    private Object getReactTextUpdate(TextViewSelectionObserver view, ReactStylesDiffMap props, MapBuffer state) {
        MapBuffer attributedString = state.getMapBuffer(0);
        MapBuffer paragraphAttributes = state.getMapBuffer(1);
        Spannable spanned = TextLayoutManagerMapBuffer.getOrCreateSpannableForText(view.getContext(), attributedString, this.mReactTextViewManagerCallback);
        view.setSpanned(spanned);
        int textBreakStrategy = TextAttributeProps.getTextBreakStrategy(paragraphAttributes.getString(2));
        return new ReactTextUpdate(spanned, -1, false, TextAttributeProps.getTextAlignment(props, TextLayoutManagerMapBuffer.isRTL(attributedString)), textBreakStrategy, TextAttributeProps.getJustificationMode(props));
    }

    @Nullable
    public Map getExportedCustomDirectEventTypeConstants() {
        Map<String, Object> baseEventTypeConstants = super.getExportedCustomDirectEventTypeConstants();
        Map<String, Object> eventTypeConstants = baseEventTypeConstants == null ? new HashMap() : baseEventTypeConstants;
        ((Map)eventTypeConstants).putAll(MapBuilder.of("topTextLayout", MapBuilder.of("registrationName", "onTextLayout"), "topInlineViewLayout", MapBuilder.of("registrationName", "onInlineViewLayout")));
        return (Map)eventTypeConstants;
    }

    public long measure(Context context, ReadableMap localData, ReadableMap props, ReadableMap state, float width, YogaMeasureMode widthMode, float height, YogaMeasureMode heightMode, @Nullable float[] attachmentsPositions) {
        return TextLayoutManager.measureText(context, localData, props, width, widthMode, height, heightMode, this.mReactTextViewManagerCallback, attachmentsPositions);
    }

    public long measure(Context context, MapBuffer localData, MapBuffer props, @Nullable MapBuffer state, float width, YogaMeasureMode widthMode, float height, YogaMeasureMode heightMode, @Nullable float[] attachmentsPositions) {
        return TextLayoutManagerMapBuffer.measureText(context, localData, props, width, widthMode, height, heightMode, this.mReactTextViewManagerCallback, attachmentsPositions);
    }

    public void setPadding(TextViewSelectionObserver view, int left, int top, int right, int bottom) {
        view.setPadding(left, top, right, bottom);
    }
}

==> react-native-highlightable-text-1.6.0.tgz: package/android/src/main/java/com/alentoma/selectabletext/CustomReactTextViewManager.java <==
package com.alentoma.selectabletext;

import android.content.Context;
import android.text.Spannable;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import com.facebook.react.R.id;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableNativeMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.common.annotations.VisibleForTesting;
import com.facebook.react.common.mapbuffer.MapBuffer;
import com.facebook.react.module.annotations.ReactModule;
import com.facebook.react.uimanager.IViewManagerWithChildren;
import com.facebook.react.uimanager.ReactAccessibilityDelegate;
import com.facebook.react.uimanager.ReactStylesDiffMap;
import com.facebook.react.uimanager.StateWrapper;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.views.text.ReactTextAnchorViewManager;
import com.facebook.react.views.text.ReactTextShadowNode;
import com.facebook.react.views.text.ReactTextUpdate;
import com.facebook.react.views.text.ReactTextView;
import com.facebook.react.views.text.ReactTextViewManagerCallback;
import com.facebook.react.views.text.TextAttributeProps;
import com.facebook.react.views.text.TextInlineImageSpan;
import com.facebook.react.views.text.TextLayoutManager;
import com.facebook.react.views.text.TextLayoutManagerMapBuffer;
import com.facebook.yoga.YogaMeasureMode;
import java.util.HashMap;
import java.util.Map;

/*
    This is an exact copy of ReactTextViewManager, except it uses our custom elements like CustomReactClickableSpan, TextViewSelectionObserver.
*/
public class CustomReactTextViewManager extends ReactTextAnchorViewManager<TextViewSelectionObserver, ReactTextShadowNode> implements IViewManagerWithChildren {
    private static final short TX_STATE_KEY_ATTRIBUTED_STRING = 0;
    private static final short TX_STATE_KEY_PARAGRAPH_ATTRIBUTES = 1;
    private static final short TX_STATE_KEY_HASH = 2;
    private static final short TX_STATE_KEY_MOST_RECENT_EVENT_COUNT = 3;
    @VisibleForTesting
    public static final String REACT_CLASS = "RCTText";
    @Nullable
    protected ReactTextViewManagerCallback mReactTextViewManagerCallback;

    public CustomReactTextViewManager() {
        this((ReactTextViewManagerCallback)null);
    }

    public CustomReactTextViewManager(@Nullable ReactTextViewManagerCallback reactTextViewManagerCallback) {
        this.mReactTextViewManagerCallback = reactTextViewManagerCallback;
        this.setupViewRecycling();
    }

    protected TextViewSelectionObserver prepareToRecycleView(@NonNull ThemedReactContext reactContext, TextViewSelectionObserver view) {
        super.prepareToRecycleView(reactContext, view);
//        view.recycleView();
        this.setSelectionColor(view, (Integer)null);
        return view;
    }

    public String getName() {
        return "RCTText";
    }

    public TextViewSelectionObserver createViewInstance(ThemedReactContext context) {
        return new TextViewSelectionObserver(context);
    }

    public void updateExtraData(TextViewSelectionObserver view, Object extraData) {
        ReactTextUpdate update = (ReactTextUpdate)extraData;
        Spannable spannable = update.getText();
        if (update.containsImages()) {
            TextInlineImageSpan.possiblyUpdateInlineImageSpans(spannable, view);
        }

        view.setText(update);
        CustomReactClickableSpan[] clickableSpans = (CustomReactClickableSpan[])spannable.getSpans(0, update.getText().length(), CustomReactClickableSpan.class);
        if (clickableSpans.length > 0) {
            view.setTag(id.accessibility_links, new ReactAccessibilityDelegate.AccessibilityLinks(clickableSpans, spannable));
            ReactAccessibilityDelegate.resetDelegate(view, view.isFocusable(), view.getImportantForAccessibility());
        }

    }

    public ReactTextShadowNode createShadowNodeInstance() {
        return new ReactTextShadowNode(this.mReactTextViewManagerCallback);
    }

    public ReactTextShadowNode createShadowNodeInstance(@Nullable ReactTextViewManagerCallback reactTextViewManagerCallback) {
        return new ReactTextShadowNode(reactTextViewManagerCallback);
    }

    public Class<ReactTextShadowNode> getShadowNodeClass() {
        return ReactTextShadowNode.class;
    }

    protected void onAfterUpdateTransaction(TextViewSelectionObserver view) {
        super.onAfterUpdateTransaction(view);
        view.updateView();
    }

    public boolean needsCustomLayoutForChildren() {
        return true;
    }

    public Object updateState(TextViewSelectionObserver view, ReactStylesDiffMap props, StateWrapper stateWrapper) {
        MapBuffer stateMapBuffer = stateWrapper.getStateDataMapBuffer();
        if (stateMapBuffer != null) {
            return this.getReactTextUpdate(view, props, stateMapBuffer);
        } else {
            ReadableNativeMap state = stateWrapper.getStateData();
            if (state == null) {
                return null;
            } else {
                ReadableMap attributedString = state.getMap("attributedString");
                ReadableMap paragraphAttributes = state.getMap("paragraphAttributes");
                Spannable spanned = TextLayoutManager.getOrCreateSpannableForText(view.getContext(), attributedString, this.mReactTextViewManagerCallback);
                view.setSpanned(spanned);
                int textBreakStrategy = TextAttributeProps.getTextBreakStrategy(paragraphAttributes.getString("textBreakStrategy"));
                return new ReactTextUpdate(spanned, state.hasKey("mostRecentEventCount") ? state.getInt("mostRecentEventCount") : -1, false, TextAttributeProps.getTextAlignment(props, TextLayoutManager.isRTL(attributedString), View.TEXT_ALIGNMENT_VIEW_START), textBreakStrategy, TextAttributeProps.getJustificationMode(props, View.TEXT_ALIGNMENT_VIEW_START));
            }
        }
    }

    private Object getReactTextUpdate(TextViewSelectionObserver view, ReactStylesDiffMap props, MapBuffer state) {
        MapBuffer attributedString = state.getMapBuffer(0);
        MapBuffer paragraphAttributes = state.getMapBuffer(1);
        Spannable spanned = TextLayoutManagerMapBuffer.getOrCreateSpannableForText(view.getContext(), attributedString, this.mReactTextViewManagerCallback);
        view.setSpanned(spanned);
        int textBreakStrategy = TextAttributeProps.getTextBreakStrategy(paragraphAttributes.getString(2));
        return new ReactTextUpdate(spanned, -1, false, TextAttributeProps.getTextAlignment(props, TextLayoutManagerMapBuffer.isRTL(attributedString), View.TEXT_ALIGNMENT_VIEW_START), textBreakStrategy, TextAttributeProps.getJustificationMode(props, View.TEXT_ALIGNMENT_VIEW_START));
    }

    @Nullable
    public Map getExportedCustomDirectEventTypeConstants() {
        Map<String, Object> baseEventTypeConstants = super.getExportedCustomDirectEventTypeConstants();
        Map<String, Object> eventTypeConstants = baseEventTypeConstants == null ? new HashMap() : baseEventTypeConstants;
        ((Map)eventTypeConstants).putAll(MapBuilder.of("topTextLayout", MapBuilder.of("registrationName", "onTextLayout"), "topInlineViewLayout", MapBuilder.of("registrationName", "onInlineViewLayout")));
        return (Map)eventTypeConstants;
    }

    public long measure(Context context, ReadableMap localData, ReadableMap props, ReadableMap state, float width, YogaMeasureMode widthMode, float height, YogaMeasureMode heightMode, @Nullable float[] attachmentsPositions) {
        return TextLayoutManager.measureText(context, localData, props, width, widthMode, height, heightMode, this.mReactTextViewManagerCallback, attachmentsPositions);
    }

    public long measure(Context context, MapBuffer localData, MapBuffer props, @Nullable MapBuffer state, float width, YogaMeasureMode widthMode, float height, YogaMeasureMode heightMode, @Nullable float[] attachmentsPositions) {
        return TextLayoutManagerMapBuffer.measureText(context, localData, props, width, widthMode, height, heightMode, this.mReactTextViewManagerCallback, attachmentsPositions);
    }

    public void setPadding(TextViewSelectionObserver view, int left, int top, int right, int bottom) {
        view.setPadding(left, top, right, bottom);
    }
}
